@@ -19,7 +19,6 @@ from dulwich.objects import ShaFile
 from dulwich.pack import PackData, PackInflater
 
 from swh.core.statsd import Statsd
-from swh.loader.core.loader import DVCSLoader
 from swh.loader.exception import NotFound
 from swh.model import hashutil
 from swh.model.model import (
@@ -35,6 +34,7 @@ from swh.storage.algos.snapshot import snapshot_get_latest
 from swh.storage.interface import StorageInterface
 
 from . import converters, dumb, utils
+from .base import BaseGitLoader
 from .utils import HexBytes
 
 logger = logging.getLogger(__name__)
@@ -84,7 +84,7 @@ class RepoRepresentation:
             for branch_name, branch in base_snapshot.branches.items():
                 if not branch or branch.target_type == TargetType.ALIAS:
                     continue
-                local_heads.add(hashutil.hash_to_hex(branch.target).encode())
+                local_heads.add(HexBytes(hashutil.hash_to_bytehex(branch.target)))
 
         self.heads = local_heads
 
@@ -121,7 +121,7 @@ class FetchPackReturn:
     pack_size: int
 
 
-class GitLoader(DVCSLoader):
+class GitLoader(BaseGitLoader):
     """A bulk loader for a git repository
 
     Emits the following statsd stats:
@@ -188,28 +188,8 @@ class GitLoader(DVCSLoader):
         """Fetch a pack from the origin"""
 
         pack_buffer = SpooledTemporaryFile(max_size=self.temp_file_cutoff)
-
-        # Hardcode the use of the tcp transport (for GitHub origins)
-
-        # Even if the Dulwich API lets us process the packfile in chunks as it's
-        # received, the HTTP transport implementation needs to entirely allocate
-        # the packfile in memory *twice*, once in the HTTP library, and once in
-        # a BytesIO managed by Dulwich, before passing chunks to the `do_pack`
-        # method Overall this triples the memory usage before we can even try to
-        # interrupt the loader before it overruns its memory limit.
-
-        # In contrast, the Dulwich TCP transport just gives us the read handle
-        # on the underlying socket, doing no processing or copying of the bytes.
-        # We can interrupt it as soon as we've received too many bytes.
-
         transport_url = origin_url
 
-        # Temporarily Disabled due to GitHub removing support for the tcp transport. See
-        # https://forge.softwareheritage.org/T3544
-        #
-        # if transport_url.startswith("https://github.com/"):
-        #     transport_url = "git" + transport_url[5:]
-
         logger.debug("Transport url to communicate with server: %s", transport_url)
 
         client, path = dulwich.client.get_transport_and_path(
@@ -286,9 +266,9 @@ class GitLoader(DVCSLoader):
                 self.base_snapshots.append(prev_snapshot)
 
             if self.parent_origins is not None:
-                # If this is the first time we load this origin and it is a forge
-                # fork, load incrementally from one of the origins it was forked from,
-                # closest parent first
+
+                # If this origin is a forge fork, load incrementally from the
+                # origins it was forked from
                 for parent_origin in self.parent_origins:
                     parent_snapshot = self.get_full_snapshot(parent_origin.url)
                     if parent_snapshot is not None:
